# Security Policy

## Supported Versions

amati is in alpha, 0.x will remain supported until 1.0 is released.

## Reporting a Vulnerability

If you think you have identified a security issue with amati, please do not open a public issue. To responsibly report a security issue, please navigate to the "Security" tab, and click ["Report a vulnerability"](https://github.com/gwyli/amati/security/advisories/new).

Please include as much detail as necessary in your report. A minimal reproducible example will help the maintainers address the issue faster.

You should expect disclosed vulnerabilities to be remediated within 7 days. A PR to do so is gratefully received.

Thank you!
